==> MediaWikiLanguageExtensionBundle-2012.12.tar.bz2: extensions/cldr/CldrNames/CldrNamesMg.php <==
<?php

$languageNames = array(
'ak' => 'Akan',
'am' => 'Amharika',
'ar' => 'Arabo',
'be' => 'Bielorosy',
'bg' => 'Biolgara',
'bn' => 'Bengali',
'cs' => 'Tseky',
'de' => 'Alemanina',
'el' => 'Grika',
'en' => 'Anglisy',
'es' => 'Espaniola',
'fa' => 'Persa',
'fr' => 'Frantsay',
'ha' => 'haoussa',
'hi' => 'hindi',
'hu' => 'hongroà',
'id' => 'Indonezianina',
'ig' => 'igbo',
'it' => 'Italianina',
'ja' => 'Japoney',
'jv' => 'Javaney',
'km' => 'khmer',
'ko' => 'Koreanina',
'mg' => 'Malagasy',
'ms' => 'Malay',
'my' => 'Birmana',
'ne' => 'Nepale',
'nl' => 'Holandey',
'pa' => 'Penjabi',
'pl' => 'Poloney',
'pt' => 'Portiogey',
'ro' => 'Romanianina',
'ru' => 'Rosianina',
'rw' => 'Roande',
'so' => 'Somalianina',
'sv' => 'Soisa',
'ta' => 'Tamoila',
'th' => 'Taioaney',
'tr' => 'Tiorka',
'uk' => 'Okrainianina',
'ur' => 'Ordò',
'vi' => 'Vietnamianina',
'yo' => 'Yôrobà',
'zh' => 'Sinoa, Mandarin',
'zu' => 'Zolò',
);

$currencyNames = array(
'AED' => 'Dirham',
'AOA' => 'kwanza angoley',
'AUD' => 'Dolara aostralianina',
'BHD' => 'dinar bahreïni',
'BIF' => 'Farantsa Borondi',
'BWP' => 'Pola botsoaney',
'CAD' => 'Dôlara Kanadianina',
'CDF' => 'Farantsa kôngôley',
'CHF' => 'Farantsa soisa',
'CNY' => 'Yoan sinoa Renminbi',
'CVE' => 'Escudo',
'DJF' => 'Farantsa Djibotianina',
'DZD' => 'Dinara alzerianina',
'EGP' => 'vola venty ejipsiana',
'ERN' => 'Nakfà Eritreanina',
'ETB' => 'Bir etiopianina',
'EUR' => 'Eoro',
'GBP' => 'livre sterling',
'GHC' => 'cédi',
'GMD' => 'Dalasi gambianina',
'GNS' => 'Farantsa Gineanina',
'INR' => 'Ropia Indianina',
'JPY' => 'Yen Japoney',
'KES' => 'Shilling kenianina',
'KMF' => 'Farantsa Komorianina',
'LRD' => 'Dôlara Liberianina',
'LSL' => 'Loti',
'LYD' => 'Dinara Libyanina',
'MAD' => 'Dirham marokianina',
'MGA' => 'Ariary',
'MRO' => 'Ouguiya moritanianina',
'MUR' => 'Ropia maorisianina',
'MWK' => 'kwacha malawite',
'MZM' => 'Metikaly',
'NAD' => 'Dolara namibianina',
'NGN' => 'Naira nigerianina',
'RWF' => 'Farantsa Roande',
'SAR' => 'Rial saodianina',
'SCR' => 'Ropia Seysheloà',
'SDG' => 'Dinara Sodaney',
'SDP' => 'livre soudanaise (1956–2007)',
'SHP' => 'livre de Sainte-Hélène',
'SLL' => 'Leone',
'SOS' => 'Shilling somalianina',
'STD' => 'Dobra',
'SZL' => 'Lilangeni',
'TND' => 'Dinar tonizianina',
'TZS' => 'Shilling tanzanianina',
'UGX' => 'Shilling ogandianina',
'USD' => 'Dolara amerikanina',
'XAF' => 'Farantsa CFA (BEAC)',
'XOF' => 'Farantsa CFA (BCEAO)',
'ZAR' => 'Rand afrikanina tatsimo',
'ZMK' => 'Kwacha zambianina',
'ZWD' => 'Dôlara Zimbaboeanina',
);

$countryNames = array(
'AD' => 'Andorra',
'AE' => 'Emirà Arabo mitambatra',
'AF' => 'Afghanistan',
'AG' => 'Antiga sy Barboda',
'AI' => 'Anguilla',
'AL' => 'Albania',
'AM' => 'Armenia',
'AN' => 'Vondronosy karaiba holandey',
'AO' => 'Angola',
'AR' => 'Arzantina',
'AS' => 'Samoa amerikanina',
'AT' => 'Aotrisy',
'AU' => 'Aostralia',
'AW' => 'Arobà',
'AZ' => 'Azerbaidjan',
'BA' => 'Bosnia sy Herzegovina',
'BB' => 'Barbady',
'BD' => 'Bangladesy',
'BE' => 'Belzika',
'BF' => 'Borkina Faso',
'BG' => 'Biolgaria',
'BH' => 'Bahrain',
'BI' => 'Borondi',
'BJ' => 'Benin',
'BM' => 'Bermioda',
'BN' => 'Brunei',
'BO' => 'Bolivia',
'BR' => 'Brezila',
'BS' => 'Bahamas',
'BT' => 'Bhotana',
'BW' => 'Botsoana',
'BY' => 'Belarosy',
'BZ' => 'Belize',
'CA' => 'Kanada',
'CD' => 'Repoblikan\'i Kongo',
'CF' => 'Repoblika Ivon\'Afrika',
'CG' => 'Kôngô',
'CH' => 'Soisa',
'CI' => 'Côte d’Ivoire',
'CK' => 'Nosy Kook',
'CL' => 'Shili',
'CM' => 'Kamerona',
'CN' => 'Sina',
'CO' => 'Kôlômbia',
'CR' => 'Kosta Rikà',
'CU' => 'Kiobà',
'CV' => 'Nosy Cap-Vert',
'CY' => 'Sypra',
'CZ' => 'Repoblikan\'i Tseky',
'DE' => 'Alemaina',
'DJ' => 'Djiboti',
'DK' => 'Danmarka',
'DM' => 'Dominika',
'DO' => 'Repoblika Dominikanina',
'DZ' => 'Alzeria',
'EC' => 'Ekoatera',
'EE' => 'Estonia',
'EG' => 'Ejypta',
'ER' => 'Eritrea',
'ES' => 'Espaina',
'ET' => 'Ethiopia',
'FI' => 'Finlandy',
'FJ' => 'Fidji',
'FK' => 'Nosy Falkand',
'FM' => 'Mikrônezia',
'FR' => 'Frantsa',
'GA' => 'Gabon',
'GB' => 'Angletera',
'GD' => 'Grenady',
'GE' => 'Zeorzia',
'GF' => 'Guyana frantsay',
'GH' => 'Ghana',
'GI' => 'Zibraltara',
'GL' => 'Groenland',
'GM' => 'Gambia',
'GN' => 'Ginea',
'GP' => 'Goadelopy',
'GQ' => 'Guinea Ekoatera',
'GR' => 'Gresy',
'GT' => 'Goatemalà',
'GU' => 'Guam',
'GW' => 'Giné-Bisao',
'GY' => 'Guyana',
'HN' => 'Hondiorasy',
'HR' => 'Kroasia',
'HT' => 'Haiti',
'HU' => 'Hongria',
'ID' => 'Indonezia',
'IE' => 'Irlandy',
'IL' => 'Israely',
'IN' => 'Indy',
'IO' => 'Faridranomasina indiana britanika',
'IQ' => 'Irak',
'IR' => 'Iran',
'IS' => 'Islandy',
'IT' => 'Italia',
'JM' => 'Jamaïka',
'JO' => 'Jordania',
'JP' => 'Japana',
'KE' => 'Kenya',
'KG' => 'Kiordistan',
'KH' => 'Kambôdja',
'KI' => 'Kiribati',
'KM' => 'Kômaoro',
'KN' => 'Saint-Christophe-et-Niévès',
'KP' => 'Korea Avaratra',
'KR' => 'Korea Atsimo',
'KW' => 'Kôeity',
'KY' => 'Nosy Kayman',
'KZ' => 'Kazakhstan',
'LA' => 'Laôs',
'LB' => 'Libana',
'LC' => 'Sainte-Lucie',
'LI' => 'Listenstein',
'LK' => 'Sri Lanka',
'LR' => 'Liberia',
'LS' => 'Lesotho',
'LT' => 'Litoania',
'LU' => 'Lioksamboro',
'LV' => 'Letonia',
'LY' => 'Libya',
'MA' => 'Marôka',
'MC' => 'Mônakô',
'MD' => 'Môldavia',
'MG' => 'Madagasikara',
'MH' => 'Nosy Marshall',
'MK' => 'Makedonia',
'ML' => 'Mali',
'MM' => 'Myanmar',
'MN' => 'Môngôlia',
'MP' => 'Nosy Mariana Atsinanana',
'MQ' => 'Martinika',
'MR' => 'Maoritania',
'MS' => 'Montserrat',
'MT' => 'Malta',
'MU' => 'Maorisy',
'MV' => 'Maldiva',
'MW' => 'Malaoì',
'MX' => 'Meksika',
'MY' => 'Malaizia',
'MZ' => 'Mozambika',
'NA' => 'Namibia',
'NC' => 'Nouvelle-Calédonie',
'NE' => 'Niger',
'NF' => 'Nosy Norfolk',
'NG' => 'Nizeria',
'NI' => 'Nikaragoà',
'NL' => 'Holanda',
'NO' => 'Nôrvezy',
'NP' => 'Nepala',
'NR' => 'Naorò',
'NU' => 'Nioé',
'NZ' => 'Nouvelle-Zélande',
'OM' => 'Oman',
'PA' => 'Panama',
'PE' => 'Peroa',
'PF' => 'Polynezia frantsay',
'PG' => 'Papouasie-Nouvelle-Guinée',
'PH' => 'Filipina',
'PK' => 'Pakistan',
'PL' => 'Pôlôna',
'PM' => 'Saint-Pierre-et-Miquelon',
'PN' => 'Pitkairn',
'PR' => 'Pôrtô Rikô',
'PS' => 'Palestina',
'PT' => 'Pôrtiogala',
'PW' => 'Palao',
'PY' => 'Paragoay',
'QA' => 'Katar',
'RE' => 'Larenion',
'RO' => 'Romania',
'RU' => 'Rosia',
'RW' => 'Roanda',
'SA' => 'Arabia saodita',
'SB' => 'Nosy Salomona',
'SC' => 'Seyshela',
'SD' => 'Sodan',
'SE' => 'Soedy',
'SG' => 'Singaporo',
'SH' => 'Sainte-Hélène',
'SI' => 'Slovenia',
'SK' => 'Slovakia',
'SL' => 'Sierra Leone',
'SM' => 'Saint-Marin',
'SN' => 'Senegal',
'SO' => 'Somalia',
'SR' => 'Sorinam',
'ST' => 'São Tomé-et-Príncipe',
'SV' => 'El Salvador',
'SY' => 'Syria',
'SZ' => 'Soazilandy',
'TC' => 'Nosy Turks sy Caïques',
'TD' => 'Tsady',
'TG' => 'Togo',
'TH' => 'Thailandy',
'TJ' => 'Tajikistan',
'TK' => 'Tokelao',
'TL' => 'Timor Atsinanana',
'TM' => 'Torkmenistan',
'TN' => 'Tonizia',
'TO' => 'Tongà',
'TR' => 'Torkia',
'TT' => 'Trinidad sy Tobagô',
'TV' => 'Tovalò',
'TW' => 'Taioana',
'TZ' => 'Tanzania',
'UA' => 'Okraina',
'UG' => 'Oganda',
'US' => 'Etazonia',
'UY' => 'Orogoay',
'UZ' => 'Ozbekistan',
'VA' => 'Firenen\'i Vatikana',
'VC' => 'Saint-Vincent-et-les Grenadines',
'VE' => 'Venezoelà',
'VG' => 'Nosy britanika virijiny',
'VI' => 'Nosy Virijiny Etazonia',
'VN' => 'Vietnam',
'VU' => 'Vanoatò',
'WF' => 'Wallis sy Futuna',
'WS' => 'Samoa',
'YE' => 'Yemen',
'YT' => 'Mayôty',
'ZA' => 'Afrika Atsimo',
'ZM' => 'Zambia',
'ZW' => 'Zimbaboe',
);

==> MediaWikiLanguageExtensionBundle-2013.05.tar.bz2: extensions/cldr/CldrNames/CldrNamesMg.php <==
<?php

$languageNames = array(
'ak' => 'Akan',
'am' => 'Amharika',
'ar' => 'Arabo',
'be' => 'Bielorosy',
'bg' => 'Biolgara',
'bn' => 'Bengali',
'cs' => 'Tseky',
'de' => 'Alemanina',
'el' => 'Grika',
'en' => 'Anglisy',
'es' => 'Espaniola',
'fa' => 'Persa',
'fr' => 'Frantsay',
'ha' => 'haoussa',
'hi' => 'hindi',
'hu' => 'hongroà',
'id' => 'Indonezianina',
'ig' => 'igbo',
'it' => 'Italianina',
'ja' => 'Japoney',
'jv' => 'Javaney',
'km' => 'khmer',
'ko' => 'Koreanina',
'mg' => 'Malagasy',
'ms' => 'Malay',
'my' => 'Birmana',
'ne' => 'Nepale',
'nl' => 'Holandey',
'pa' => 'Penjabi',
'pl' => 'Poloney',
'pt' => 'Portiogey',
'ro' => 'Romanianina',
'ru' => 'Rosianina',
'rw' => 'Roande',
'so' => 'Somalianina',
'sv' => 'Soisa',
'ta' => 'Tamoila',
'th' => 'Taioaney',
'tr' => 'Tiorka',
'uk' => 'Okrainianina',
'ur' => 'Ordò',
'vi' => 'Vietnamianina',
'yo' => 'Yôrobà',
'zh' => 'Sinoa, Mandarin',
'zu' => 'Zolò',
);

$currencyNames = array(
'AED' => 'Dirham',
'AOA' => 'kwanza angoley',
'AUD' => 'Dolara aostralianina',
'BHD' => 'dinar bahreïni',
'BIF' => 'Farantsa Borondi',
'BWP' => 'Pola botsoaney',
'CAD' => 'Dôlara Kanadianina',
'CDF' => 'Farantsa kôngôley',
'CHF' => 'Farantsa soisa',
'CNY' => 'Yoan sinoa Renminbi',
'CVE' => 'Escudo',
'DJF' => 'Farantsa Djibotianina',
'DZD' => 'Dinara alzerianina',
'EGP' => 'vola venty ejipsiana',
'ERN' => 'Nakfà Eritreanina',
'ETB' => 'Bir etiopianina',
'EUR' => 'Eoro',
'GBP' => 'livre sterling',
'GHC' => 'cédi',
'GMD' => 'Dalasi gambianina',
'GNS' => 'Farantsa Gineanina',
'INR' => 'Ropia Indianina',
'JPY' => 'Yen Japoney',
'KES' => 'Shilling kenianina',
'KMF' => 'Farantsa Komorianina',
'LRD' => 'Dôlara Liberianina',
'LSL' => 'Loti',
'LYD' => 'Dinara Libyanina',
'MAD' => 'Dirham marokianina',
'MGA' => 'Ariary',
'MRO' => 'Ouguiya moritanianina',
'MUR' => 'Ropia maorisianina',
'MWK' => 'kwacha malawite',
'MZM' => 'Metikaly',
'NAD' => 'Dolara namibianina',
'NGN' => 'Naira nigerianina',
'RWF' => 'Farantsa Roande',
'SAR' => 'Rial saodianina',
'SCR' => 'Ropia Seysheloà',
'SDG' => 'Dinara Sodaney',
'SDP' => 'livre soudanaise (1956–2007)',
'SHP' => 'livre de Sainte-Hélène',
'SLL' => 'Leone',
'SOS' => 'Shilling somalianina',
'STD' => 'Dobra',
'SZL' => 'Lilangeni',
'TND' => 'Dinar tonizianina',
'TZS' => 'Shilling tanzanianina',
'UGX' => 'Shilling ogandianina',
'USD' => 'Dolara amerikanina',
'XAF' => 'Farantsa CFA (BEAC)',
'XOF' => 'Farantsa CFA (BCEAO)',
'ZAR' => 'Rand afrikanina tatsimo',
'ZMK' => 'Kwacha zambianina (1968-2012)',
'ZMW' => 'Kwacha zambianina',
'ZWD' => 'Dôlara Zimbaboeanina',
);

$countryNames = array(
'AD' => 'Andorra',
'AE' => 'Emirà Arabo mitambatra',
'AF' => 'Afghanistan',
'AG' => 'Antiga sy Barboda',
'AI' => 'Anguilla',
'AL' => 'Albania',
'AM' => 'Armenia',
'AN' => 'Vondronosy karaiba holandey',
'AO' => 'Angola',
'AR' => 'Arzantina',
'AS' => 'Samoa amerikanina',
'AT' => 'Aotrisy',
'AU' => 'Aostralia',
'AW' => 'Arobà',
'AZ' => 'Azerbaidjan',
'BA' => 'Bosnia sy Herzegovina',
'BB' => 'Barbady',
'BD' => 'Bangladesy',
'BE' => 'Belzika',
'BF' => 'Borkina Faso',
'BG' => 'Biolgaria',
'BH' => 'Bahrain',
'BI' => 'Borondi',
'BJ' => 'Benin',
'BM' => 'Bermioda',
'BN' => 'Brunei',
'BO' => 'Bolivia',
'BR' => 'Brezila',
'BS' => 'Bahamas',
'BT' => 'Bhotana',
'BW' => 'Botsoana',
'BY' => 'Belarosy',
'BZ' => 'Belize',
'CA' => 'Kanada',
'CD' => 'Repoblikan\'i Kongo',
'CF' => 'Repoblika Ivon\'Afrika',
'CG' => 'Kôngô',
'CH' => 'Soisa',
'CI' => 'Côte d’Ivoire',
'CK' => 'Nosy Kook',
'CL' => 'Shili',
'CM' => 'Kamerona',
'CN' => 'Sina',
'CO' => 'Kôlômbia',
'CR' => 'Kosta Rikà',
'CU' => 'Kiobà',
'CV' => 'Nosy Cap-Vert',
'CY' => 'Sypra',
'CZ' => 'Repoblikan\'i Tseky',
'DE' => 'Alemaina',
'DJ' => 'Djiboti',
'DK' => 'Danmarka',
'DM' => 'Dominika',
'DO' => 'Repoblika Dominikanina',
'DZ' => 'Alzeria',
'EC' => 'Ekoatera',
'EE' => 'Estonia',
'EG' => 'Ejypta',
'ER' => 'Eritrea',
'ES' => 'Espaina',
'ET' => 'Ethiopia',
'FI' => 'Finlandy',
'FJ' => 'Fidji',
'FK' => 'Nosy Falkand',
'FM' => 'Mikrônezia',
'FR' => 'Frantsa',
'GA' => 'Gabon',
'GB' => 'Angletera',
'GD' => 'Grenady',
'GE' => 'Zeorzia',
'GF' => 'Guyana frantsay',
'GH' => 'Ghana',
'GI' => 'Zibraltara',
'GL' => 'Groenland',
'GM' => 'Gambia',
'GN' => 'Ginea',
'GP' => 'Goadelopy',
'GQ' => 'Guinea Ekoatera',
'GR' => 'Gresy',
'GT' => 'Goatemalà',
'GU' => 'Guam',
'GW' => 'Giné-Bisao',
'GY' => 'Guyana',
'HN' => 'Hondiorasy',
'HR' => 'Kroasia',
'HT' => 'Haiti',
'HU' => 'Hongria',
'ID' => 'Indonezia',
'IE' => 'Irlandy',
'IL' => 'Israely',
'IN' => 'Indy',
'IO' => 'Faridranomasina indiana britanika',
'IQ' => 'Irak',
'IR' => 'Iran',
'IS' => 'Islandy',
'IT' => 'Italia',
'JM' => 'Jamaïka',
'JO' => 'Jordania',
'JP' => 'Japana',
'KE' => 'Kenya',
'KG' => 'Kiordistan',
'KH' => 'Kambôdja',
'KI' => 'Kiribati',
'KM' => 'Kômaoro',
'KN' => 'Saint-Christophe-et-Niévès',
'KP' => 'Korea Avaratra',
'KR' => 'Korea Atsimo',
'KW' => 'Kôeity',
'KY' => 'Nosy Kayman',
'KZ' => 'Kazakhstan',
'LA' => 'Laôs',
'LB' => 'Libana',
'LC' => 'Sainte-Lucie',
'LI' => 'Listenstein',
'LK' => 'Sri Lanka',
'LR' => 'Liberia',
'LS' => 'Lesotho',
'LT' => 'Litoania',
'LU' => 'Lioksamboro',
'LV' => 'Letonia',
'LY' => 'Libya',
'MA' => 'Marôka',
'MC' => 'Mônakô',
'MD' => 'Môldavia',
'MG' => 'Madagasikara',
'MH' => 'Nosy Marshall',
'MK' => 'Makedonia',
'ML' => 'Mali',
'MM' => 'Myanmar',
'MN' => 'Môngôlia',
'MP' => 'Nosy Mariana Atsinanana',
'MQ' => 'Martinika',
'MR' => 'Maoritania',
'MS' => 'Montserrat',
'MT' => 'Malta',
'MU' => 'Maorisy',
'MV' => 'Maldiva',
'MW' => 'Malaoì',
'MX' => 'Meksika',
'MY' => 'Malaizia',
'MZ' => 'Mozambika',
'NA' => 'Namibia',
'NC' => 'Nouvelle-Calédonie',
'NE' => 'Niger',
'NF' => 'Nosy Norfolk',
'NG' => 'Nizeria',
'NI' => 'Nikaragoà',
'NL' => 'Holanda',
'NO' => 'Nôrvezy',
'NP' => 'Nepala',
'NR' => 'Naorò',
'NU' => 'Nioé',
'NZ' => 'Nouvelle-Zélande',
'OM' => 'Oman',
'PA' => 'Panama',
'PE' => 'Peroa',
'PF' => 'Polynezia frantsay',
'PG' => 'Papouasie-Nouvelle-Guinée',
'PH' => 'Filipina',
'PK' => 'Pakistan',
'PL' => 'Pôlôna',
'PM' => 'Saint-Pierre-et-Miquelon',
'PN' => 'Pitkairn',
'PR' => 'Pôrtô Rikô',
'PS' => 'Palestina',
'PT' => 'Pôrtiogala',
'PW' => 'Palao',
'PY' => 'Paragoay',
'QA' => 'Katar',
'RE' => 'Larenion',
'RO' => 'Romania',
'RU' => 'Rosia',
'RW' => 'Roanda',
'SA' => 'Arabia saodita',
'SB' => 'Nosy Salomona',
'SC' => 'Seyshela',
'SD' => 'Sodan',
'SE' => 'Soedy',
'SG' => 'Singaporo',
'SH' => 'Sainte-Hélène',
'SI' => 'Slovenia',
'SK' => 'Slovakia',
'SL' => 'Sierra Leone',
'SM' => 'Saint-Marin',
'SN' => 'Senegal',
'SO' => 'Somalia',
'SR' => 'Sorinam',
'ST' => 'São Tomé-et-Príncipe',
'SV' => 'El Salvador',
'SY' => 'Syria',
'SZ' => 'Soazilandy',
'TC' => 'Nosy Turks sy Caïques',
'TD' => 'Tsady',
'TG' => 'Togo',
'TH' => 'Thailandy',
'TJ' => 'Tajikistan',
'TK' => 'Tokelao',
'TL' => 'Timor Atsinanana',
'TM' => 'Torkmenistan',
'TN' => 'Tonizia',
'TO' => 'Tongà',
'TR' => 'Torkia',
'TT' => 'Trinidad sy Tobagô',
'TV' => 'Tovalò',
'TW' => 'Taioana',
'TZ' => 'Tanzania',
'UA' => 'Okraina',
'UG' => 'Oganda',
'US' => 'Etazonia',
'UY' => 'Orogoay',
'UZ' => 'Ozbekistan',
'VA' => 'Firenen\'i Vatikana',
'VC' => 'Saint-Vincent-et-les Grenadines',
'VE' => 'Venezoelà',
'VG' => 'Nosy britanika virijiny',
'VI' => 'Nosy Virijiny Etazonia',
'VN' => 'Vietnam',
'VU' => 'Vanoatò',
'WF' => 'Wallis sy Futuna',
'WS' => 'Samoa',
'YE' => 'Yemen',
'YT' => 'Mayôty',
'ZA' => 'Afrika Atsimo',
'ZM' => 'Zambia',
'ZW' => 'Zimbaboe',
);
